==> notabene-cli-0.0.1.tar.gz: notabene-cli-0.0.1/README.md <==
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Read the Docs](https://readthedocs.org/projects/notabene-cli/badge/?version=latest)](https://notabene-cli.readthedocs.io/en/latest/?badge=latest)
![Code Quality](https://github.com/JeroenPeterBos/notabene-cli/actions/workflows/code-quality.yaml/badge.svg)
![Platform Tests](https://github.com/JeroenPeterBos/notabene-cli/actions/workflows/platform-tests.yaml/badge.svg)

<p align="center">
    <img width="60%" src="docs/_static/images/logo_wide.svg">
</p>

Bring best practices from software engineering to your jupyter notebooks using [NotaBene](https://github.com/JeroenPeterBos/notabene-cli).

* Documentation: https://notabene-cli.readthedocs.io
* Website: https://notabene.cloud

## Getting Started

The project's documentation contains a section to help you
[get started](https://notabene-cli.readthedocs.io/en/latest/getting_started.html).

### Installation

Install [NotaBene](https://github.com/JeroenPeterBos/notabene-cli) using:

```
pip install notabene-cli
```

## Development Prerequisites

If you're going to be working in the code (rather than just using the library), you'll want a few utilities.

* [GNU Make](https://www.gnu.org/software/make/)

## Authors

* **Jeroen Peter Bos** - *Initial work* - [github](https://github.com/JeroenPeterBos)

See also the list of [contributors](https://github.com/JeroenPeterBos/notabene/contributors) who participated in this project.

## LicenseCopyright (c) Jeroen Peter Bos

All rights reserved.

==> notabene-cli-0.0.2.tar.gz: notabene-cli-0.0.2/README.md <==
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Read the Docs](https://readthedocs.org/projects/notabene-cli/badge/?version=latest)](https://notabene-cli.readthedocs.io/en/latest/?badge=latest)
![Code Quality](https://github.com/JeroenPeterBos/notabene-cli/actions/workflows/code-quality.yaml/badge.svg)
![Platform Tests](https://github.com/JeroenPeterBos/notabene-cli/actions/workflows/platform-tests.yaml/badge.svg)
![Python Versions](https://img.shields.io/pypi/pyversions/notabene-cli)
![PyPI](https://img.shields.io/pypi/v/notabene-cli)

<p align="center">
    <img width="60%" src="https://raw.githubusercontent.com/JeroenPeterBos/notabene-cli/main/docs/_static/images/logo_wide.svg">

</p>

<p align="center">

Bring best practices from software engineering to your jupyter notebooks using [NotaBene](https://github.com/JeroenPeterBos/notabene-cli). 

</p>

Knowledge is best transfered when its presentation is familiar. Notabene enables you to standardize and simplify knowledge transfer on data insights.

* Code Base: https://github.com/JeroenPeterBos/notabene-cli
* Documentation: https://notabene-cli.readthedocs.io

## Features

* Notebook Templates
    * Create and use your own library of notebook templates

## Getting Started

The project's documentation contains a section to help you
[get started](https://notabene-cli.readthedocs.io/en/latest/getting_started.html).

### Installation

Install [NotaBene](https://github.com/JeroenPeterBos/notabene-cli) using:

```
pip install notabene-cli
```

For more information on how to get started **[visit the documentation](https://notabene-cli.readthedocs.io/en/latest)**.

## Development Prerequisites

If you're going to be working in the code (rather than just using the library), you'll want a few utilities.

* [GNU Make](https://www.gnu.org/software/make/)

## Authors

* **Jeroen Peter Bos** - *Initial work* - [github](https://github.com/JeroenPeterBos)

See also the list of [contributors](https://github.com/JeroenPeterBos/notabene/contributors) who participated in this project.

## LicenseCopyright (c) Jeroen Peter Bos

All rights reserved.
